@@ -9,5 +9,5 @@ def test_dataset_with_alignments():
     ds = dataset.SpeechDataset(meta, 16000, alignments_path)
 
     assert len(ds) == 2
-    assert ds[0].alignment.word_segments[0].label == "one"
-    assert ds[1].alignment.word_segments[0].label == "two"
+    assert ds[0].alignment.words_cleaned[0].label == "one"
+    assert ds[1].alignment.words_cleaned[0].label == "two"
